@@ -5,10 +5,14 @@
 #' through \url{http://www.shinyapps.io/}. The function \code{\link{mirtCAT_preamble}} must be 
 #' run \emph{before} this function is called. The object is executed by calling \code{\link{runApp}}.
 #' 
-#' @param sessionName the unique name of the session (see \code{\link{mirtCAT}} for details)
+# @param sessionName the unique name of the session (see \code{\link{mirtCAT}} for details)
 #' 
 #' @param ui a shiny UI function used to define the interface. If \code{NULL}, the default one will be used. 
 #'   See \code{mirtCAT:::default_UI} for the internal code
+#'   
+#' @param host_server logical; is \code{createShinyGUI()} being used on a remote server or executed locally?
+#'   When \code{TRUE} any calls to \code{\link{stopApp}} are suppressed to allow for multiple sessions to
+#'   be executed. Note that \code{FALSE} gives the same behaviour as the GUI in \code{\link{mirtCAT}}
 #' 
 #' @export createShinyGUI
 #' 
@@ -29,22 +33,26 @@
 #' @examples 
 #' \dontrun{
 #' 
-#' sessionName <- 'My session'
-#' mirtCAT_preamble(sessionName=sessionName, df=df)
-#' runApp(createShinyGUI(), port = 8000)
+#' mirtCAT_preamble(df=df)
+#' runApp(createShinyGUI(host_server = FALSE), port = 8000) # run locally
 #' 
-#' person <- getPerson(sessionName)
+#' person <- getPerson()
 #' summary(person)
 #' 
+#' runApp(createShinyGUI(), port = 8000) # for remote server hosting
+#' 
 #' } 
-createShinyGUI <- function(sessionName, ui = NULL){
-    if(missing(sessionName)) stop('Must specify sessionName')
-    on.exit(.MCE[[sessionName]]$preamble_defined <- .MCE[[sessionName]]$start_time <- NULL)
+createShinyGUI <- function(ui = NULL, host_server = TRUE){
+    sessionName <- 'MASTER'
+    on.exit(.MCE[[sessionName]]$preamble_defined <- .MCE[[sessionName]]$start_time <- 
+                .MCE[[sessionName]]$initial_start_time <- NULL)
     if(is.null(.MCE[[sessionName]]$preamble_defined))
         stop('Please use a fresh mirtCAT_preamble() call prior to calling createShinyGUI().')
     if(is.null(ui)) ui <- default_UI
-    server2 <- server
-    txt <- parse(text=sprintf("getSessionName <- function() \'%s\'", sessionName))
-    body(server2)[[2]] <- substitute(eval(txt))
-    return(shinyApp(ui=ui(sessionName), server=server2))
+    .MCE[[sessionName]]$host_server <- host_server
+    # server2 <- server
+    # txt <- parse(text=sprintf("getSessionName <- function() \'%s\'", sessionName))
+    # body(server2)[[2]] <- substitute(eval(txt))
+    # return(shinyApp(ui=ui(sessionName), server=server2))
+    return(shinyApp(ui=ui(), server=server))
 }
