@@ -28,7 +28,8 @@ MEPV <- function(which_not_answered, possible_patterns, person, test, design, ro
         p <- probtrace(test@EIs[[i]], person$thetas)
         P[row_loc == i] <- p
     }
-    acovstmp <- getAcovs(possible_patterns, method = 'EAP', test=test, design=design)
+    acovstmp <- getAcovs(possible_patterns, thetas=person$thetas, 
+                         method = 'EAP', test=test, design=design)
     acovs <- weighted_mat(P=P, mat=acovstmp, row_loc=row_loc, 
                           which_not_answered=which_not_answered)
     crit <- do.call(c, acovs)
@@ -60,29 +61,34 @@ InfoMats <- function(which_not_answered, person, test, thetas){
           person$info_thetas)
 }
 
-Drule <- function(which_not_answered, person, test, thetas){
+Drule <- function(which_not_answered, person, test, thetas, prior = FALSE){
+    prior_info <- person$info_thetas + if(prior) person$info_thetas_cov else 0
     .Call('ComputeCriteria', test@EIs, person$thetas, which_not_answered, 
-                              2, 0, person$info_thetas)
+                              2, 0, prior_info)
 }
 
-Trule <- function(which_not_answered, person, test, design, thetas){
+Trule <- function(which_not_answered, person, test, design, thetas, prior = FALSE){
+    prior_info <- person$info_thetas + if(prior) person$info_thetas_cov else 0
     .Call('ComputeCriteria', test@EIs, person$thetas, which_not_answered, 
-          3, design@weights, person$info_thetas)
+          3, design@weights, prior_info)
 }
 
-Arule <- function(which_not_answered, person, test, design, thetas){
+Arule <- function(which_not_answered, person, test, design, thetas, prior = FALSE){
+    prior_info <- person$info_thetas + if(prior) person$info_thetas_cov else 0
     .Call('ComputeCriteria', test@EIs, person$thetas, which_not_answered, 
-          4, design@weights, person$info_thetas)
+          4, design@weights, prior_info)
 }
 
-Wrule <- function(which_not_answered, person, test, design, thetas){
+Wrule <- function(which_not_answered, person, test, design, thetas, prior = FALSE){
+    prior_info <- person$info_thetas + if(prior) person$info_thetas_cov else 0
     .Call('ComputeCriteria', test@EIs, person$thetas, which_not_answered, 
-          5, design@weights, person$info_thetas)
+          5, design@weights, prior_info)
 }
 
-Erule <- function(which_not_answered, person, test, thetas){
+Erule <- function(which_not_answered, person, test, thetas, prior = FALSE){
+    prior_info <- person$info_thetas + if(prior) person$info_thetas_cov else 0
     .Call('ComputeCriteria', test@EIs, person$thetas, which_not_answered, 
-          6, 0, person$info_thetas)
+          6, 0, prior_info)
 }
 
 KL <- function(which_not_answered, person, test, delta, thetas, thetas2 = NULL){
